@@ -32,6 +32,19 @@ class LossFlowData(IFeaturesDict):
     def __getattr__(self, item):
         return self
 
+    @classmethod
+    def from_args(cls, *args, **kwargs):
+        for arg in args:
+            if isinstance(arg, LossFlowData):
+                return arg
+
+        for arg in kwargs.values():
+            if isinstance(arg, LossFlowData):
+                return arg
+
+        if args_are_dicts(args):
+            return cls(*args)
+
 
 class LossItems(IOut, IFlowTaskResult, ICondition):
 
@@ -56,17 +69,8 @@ class LossItems(IOut, IFlowTaskResult, ICondition):
         return self
 
 
-def get_flow_data(*args, **kwargs):
-    if len(args) == 2:
-        return LossFlowData(*args)
-
-    for arg in args:
-        if isinstance(arg, LossFlowData):
-            return arg
-
-    for arg in kwargs.values():
-        if isinstance(arg, LossFlowData):
-            return arg
+def args_are_dicts(args):
+    return len(args) == 2 and isinstance(args[0], dict) and isinstance(args[1], dict)
 
 
 def squeeze_if_needed(tensor):
@@ -156,7 +160,7 @@ class BaseMetricDecorator(nn.Module):
                                                           ctx=ctx)
 
     def forward(self, *args, **kwargs):
-        loss_flow_data = get_flow_data(*args, **kwargs)
+        loss_flow_data = LossFlowData.from_args(*args, **kwargs)
         return self.postprocess_results(self.compute_with_precondition(loss_flow_data))
 
     def compute_with_precondition(self, loss_flow_data):
@@ -232,8 +236,7 @@ class TaskFlowLoss(nn.Module):
         :param args:
         :return:
         """
-        is_root = len(args) == 2
-        if is_root:
+        if args_are_dicts(args):
             outputs, targets = args
         else:
             loss_flow_data = args[0]
@@ -248,6 +251,7 @@ class TaskFlowLoss(nn.Module):
         loss_items = torch.zeros(1, dtype=value.dtype, device=value.device)
         flow_result = self.flow(self, LossFlowData(outputs, targets), LossItems(loss_items))
 
+        is_root = self.prefix == ''
         if not is_root:
             return LossItems(flow_result.loss_items)
 
